==> nextcloud-12.0.4-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/ca.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendari",
    "Todos" : "Tots",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} ha creat el calendari {calendar}",
    "You created calendar {calendar}" : "Vosté ha creat el calentari {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ha esborrat el calendari {calendar}",
    "You deleted calendar {calendar}" : "Voste ha esborrat el calendari {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ha actualitzat el calendari {calendar}",
    "You updated calendar {calendar}" : "Vosté ha actualitzat el calendari {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha compartit el calendari {calendar} amb vosté",
    "You shared calendar {calendar} with {user}" : "Vosté ha compartit el calendari {calendar} amb {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} ha compartit el calendari {calendar} amb {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} no ha compartit el calendari {calendar}  amb vosté",
    "You unshared calendar {calendar} from {user}" : "Vosté no ha compartit el calendari {calendar} amb {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} no ha compartit el calendari {calendar}  amb {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} no comparteixen el calendari {calendar} de si mateixos",
    "You shared calendar {calendar} with group {group}" : "Has compartit el calendari {calendar} amb el grup {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} ha compartit el calendari {calendar} amb el grup {group}",
    "You unshared calendar {calendar} from group {group}" : "Has desactivat el calendari {calendar} del grup {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} calendari no publicat {calendar} del grup {grup}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} ha creat l'esdeveniment {event} al calendari {calendar}",
    "You created event {event} in calendar {calendar}" : "Heu creat l'esdeveniment {event} al calendari {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eliminat esdeveniment {esdeveniment} del calendari {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Has eliminat l'esdeveniment {event} del calendari {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} esdeveniment actualitzat {esdeveniment} al calendari {calendar}",
    "You updated event {event} in calendar {calendar}" : "Heu actualitzat l'esdeveniment {event} al calendari {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creat tot {tot} a la llista {calendar}",
    "You created todo {todo} in list {calendar}" : "Heu creat tot {tot} a la llista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} eliminat tot {tot} de la llista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Heu eliminat tot {tot} de la llista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualitzat tot {tot} a la llista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Heu actualitzat tot {tot} a la llista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} resolt tot {tot} a la llista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Has resolt la tasca {todo} de {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} ha tornat a obrir tot {tot} a la llista {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Heu tornat a obrir tot {tot} a la llista {calendar}",
    "A <strong>calendar</strong> was modified" : "El <strong>calendari</strong> has estat modificat",
    "A calendar <strong>event</strong> was modified" : "S'ha modificat un <strong> esdeveniment </strong> del calendari",
    "A calendar <strong>todo</strong> was modified" : "<strong>Tot</strong> un calendari va ser modificat",
    "Contact birthdays" : "Aniversaris dels contactes",
    "Contacts" : "Contactes",
    "Technical details" : "Detalls tècnics",
    "Remote Address: %s" : "Adreça remota: %s",
    "Request ID: %s" : "Sol·licitud ID: %s "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/ca.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendari",
    "Todos" : "Tots",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} ha creat el calendari {calendar}",
    "You created calendar {calendar}" : "Vostè ha creat el calendari {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ha esborrat el calendari {calendar}",
    "You deleted calendar {calendar}" : "Voste ha esborrat el calendari {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ha actualitzat el calendari {calendar}",
    "You updated calendar {calendar}" : "Vosté ha actualitzat el calendari {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha compartit el calendari {calendar} amb vosté",
    "You shared calendar {calendar} with {user}" : "Vosté ha compartit el calendari {calendar} amb {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} ha compartit el calendari {calendar} amb {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} no ha compartit el calendari {calendar}  amb vosté",
    "You unshared calendar {calendar} from {user}" : "Vosté no ha compartit el calendari {calendar} amb {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} no ha compartit el calendari {calendar}  amb {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} no comparteixen el calendari {calendar} de si mateixos",
    "You shared calendar {calendar} with group {group}" : "Has compartit el calendari {calendar} amb el grup {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} ha compartit el calendari {calendar} amb el grup {group}",
    "You unshared calendar {calendar} from group {group}" : "Has desactivat el calendari {calendar} del grup {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} calendari no publicat {calendar} del grup {grup}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} ha creat l'esdeveniment {event} al calendari {calendar}",
    "You created event {event} in calendar {calendar}" : "Heu creat l'esdeveniment {event} al calendari {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eliminat esdeveniment {esdeveniment} del calendari {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Has eliminat l'esdeveniment {event} del calendari {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} esdeveniment actualitzat {esdeveniment} al calendari {calendar}",
    "You updated event {event} in calendar {calendar}" : "Heu actualitzat l'esdeveniment {event} al calendari {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creat tot {tot} a la llista {calendar}",
    "You created todo {todo} in list {calendar}" : "Heu creat tot {tot} a la llista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} eliminat tot {tot} de la llista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Heu eliminat tot {tot} de la llista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualitzat tot {tot} a la llista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Heu actualitzat tot {tot} a la llista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} resolt tot {tot} a la llista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Has resolt la tasca {todo} de {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} ha tornat a obrir tot {tot} a la llista {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Heu tornat a obrir tot {tot} a la llista {calendar}",
    "A <strong>calendar</strong> was modified" : "El <strong>calendari</strong> has estat modificat",
    "A calendar <strong>event</strong> was modified" : "S'ha modificat un <strong> esdeveniment </strong> del calendari",
    "A calendar <strong>todo</strong> was modified" : "<strong>Tot</strong> un calendari va ser modificat",
    "Contact birthdays" : "Aniversaris dels contactes",
    "Contacts" : "Contactes",
    "Technical details" : "Detalls tècnics",
    "Remote Address: %s" : "Adreça remota: %s",
    "Request ID: %s" : "Sol·licitud ID: %s "
},
"nplurals=2; plural=(n != 1);");
